Support functions for tawny-mode.el
Support functions for tawny-mode.el
(check-namespace namespace)Test namespace for error condition.
Returns error message or namespace if everything is fine.
Test namespace for error condition. Returns error message or namespace if everything is fine.
(get-inferred-subclasses namespace class)Returns a string of inferred subclasses.
Returns a string of inferred subclasses.
(get-inferred-superclasses namespace class)Returns a string of inferred superclasses.
Returns a string of inferred superclasses.
(get-unsatisfiable namespace)Returns a string about unsatisfiable classes.
Returns a string about unsatisfiable classes.
(identitas id)Return a random prolong ID from the identitas library.
Return a random prolong ID from the identitas library.
(is-coherent namespace)Returns a message about the coherency of NAMESPACE
Returns a message about the coherency of NAMESPACE
(is-consistent namespace)Returns a message about the consistency of NAMESPACE
Returns a message about the consistency of NAMESPACE
(list-classes classes)Given a set of classes, returns a string representation.
Given a set of classes, returns a string representation.
(save-namespace-ontology namespace)Save ontology in the given namespace.
Save ontology in the given namespace.
(set-reasoner reasoner)Sets the reasoner factory.
Sets the reasoner factory.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |