Type based predicates for OWL.
Type based predicates for OWL.
(ann-prop? e)Return true if e is an instance of OWLAnnotationProperty.
Return true if `e` is an instance of `OWLAnnotationProperty`.
(ann-val? e)Return true if e is an instance of OWLAnnotationValue.
Return true if `e` is an instance of `OWLAnnotationValue`.
(anonymous? e)Return true if e is an instance of OWLAnonymousIndividual.
Return true if `e` is an instance of `OWLAnonymousIndividual`.
(class-exp? e)Return true if e is an instance of OWLClassExpression.
Return true if `e` is an instance of `OWLClassExpression`.
(data-prop-exp? e)Return true if e is an instance of OWLDataPropertyExpression.
Return true if `e` is an instance of `OWLDataPropertyExpression`.
(data-prop? e)Return true if e is an instance of OWLDataProperty.
Return true if `e` is an instance of `OWLDataProperty`.
(data-range? e)Return true if e is an instance of OWLDataRange.
Return true if `e` is an instance of `OWLDataRange`.
(data-type? e)Return true if e is an instance of OWLDatatype.
Return true if `e` is an instance of `OWLDatatype`.
(individual? e)Return true if e is an instance of OWLIndividual.
Return true if `e` is an instance of `OWLIndividual`.
(iri? e)Return true if e is an instance of IRI.
Return true if `e` is an instance of `IRI`.
(literal? e)Return true if e is an instance of OWLLiteral.
Return true if `e` is an instance of `OWLLiteral`.
(named? e)Return true if e is an instance of OWLNamedObject.
Return true if `e` is an instance of `OWLNamedObject`.
(obj-prop-exp? e)Return true if e is an instance of OWLObjectPropertyExpression.
Return true if `e` is an instance of `OWLObjectPropertyExpression`.
(obj-prop? e)Return true if e is an instance of OWLObjectProperty.
Return true if `e` is an instance of `OWLObjectProperty`.
(ontology? e)Return true if e is an instance of OWLOntology.
Return true if `e` is an instance of `OWLOntology`.
(owl-class? e)Return true if e is an instance of OWLClass.
Return true if `e` is an instance of `OWLClass`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |